import React, {PropTypes, cloneElement} from 'react';
import c from 'classnames';
import _ from 'lodash';
import { mapPropsOnChange } from 'recompose';

import style from './input-button-group.css';

@mapPropsOnChange(
  ['children'],
  ({children, ...props}) => ({
    children: _.isArray(children) ? children : [children],
    ...props,
  })
)
export default class extends React.Component {
  displayName: 'InputButtonGroup'
  
  static propTypes = {
    className: PropTypes.string,
    value: PropTypes.string,
    disabled: PropTypes.bool,
    required: PropTypes.bool,
    onChange: PropTypes.func,
  }

  static defaultProps = {
    onChange: () => {},
  }

  componentDidMount() {
    const { value, onChange } = this.props;

    onChange(value, this.validate(value));
  }

  componentDidUpdate(prevProps) {
    const { required, value, onChange } = this.props;

    if (prevProps.required !== required || prevProps.value !== value) {
      onChange(value, this.validate(value));
    }
  }

  validate(value) {
    const {
      required,
      onChange,
    } = this.props;

    return required && !value ? '是必要欄位' : null;
  }
  
  onChange = (e, value) => {
    this.props.onChange(value, this.validate(value), e);
  }

  render() {
    const {
      className,
      onChange,
      children,
      value,
      ...otherProps,
    } = this.props;

    return (
      <div {...otherProps} className={c(style.group, className)}>
        {children.map((item, idx) => {
          const {
            value,
            className,
          } = item.props;

          return cloneElement(item, {
            key: `button-${idx}`,
            onClick: (e) => this.onChange(e, value),
            className: c(className, style.button, value === this.props.value && style.active),
          });
        })}
      </div>
    );
  }
}