import React, {PropTypes, cloneElement} from 'react';
import moment from 'moment';
import c from 'classnames';
import { mapPropsOnChange } from 'recompose';

import InputText from '../input-text/input-text'

@mapPropsOnChange(
  ['value'],
  ({value, ...props}) => ({
    value,
    date: value ? moment(value).format('YYYY-MM-DD') : null,
    ...props,
  })
)
export default class extends React.Component {
  displayName: 'InputDate'
  
  static propTypes = {
    value: PropTypes.instanceOf(Date),
    date: PropTypes.string,
    onChange: PropTypes.func,
  }

  static defaultProps = {
    onChange: () => {},
  }

  onChange = (current, valid) => {
    const { onChange, value } = this.props;

    if (current) {
      current = moment(current);

      if (value) current = moment(value).set({
        year: current.get('year'),
        month: current.get('month'),
        date: current.get('date'),
      });

      current = current.toDate();

      onChange(current, valid);
    } else {
      onChange(value, valid);
    }
  }

  render () {
    const {
      onChange,
      value,
      date,
      ...otherProps,
    } = this.props;

    return (
      <InputText {...otherProps} onChange={this.onChange} value={date} type="date" />
    );
  }
}
