import React, {PropTypes} from 'react';
import c from 'classnames';
import InputText from '../input-text/input-text';
import InputSelectOption from './input-select-option';
import _ from 'lodash';

import style from './input-select.css';

export default class extends React.Component {
  displayName: 'InputSelect'
  
  static propTypes = {
    className: PropTypes.string,
    disabled: PropTypes.bool,
    label: PropTypes.string,
    icon: PropTypes.element,
    required: PropTypes.bool,
    onChange: PropTypes.func,
  }

  defaultProps = {
    labal: '請選擇',
    value: null,
    required: false,
    onChange: () => {},
  }

  componentDidMount() {
    const {
      value,
      onChange,
    } = this.props;
    
    onChange(value, this.validate(value));
  }

  componentDidUpdate(prevProps) {
    const {
      required,
      value,
      onChange,
    } = this.props;

    if (prevProps.required !== required || prevProps.value !== value) {
      onChange(value, this.validate(value));
    }
  }

  validate(value) {
    const { required, onChange } = this.props;

    if (required && !value) {
      return '是必要欄位';
    } else {
      return;
    }
  }
  
  onChange(e) {
    const value = e.target.value;

    this.props.onChange(value, this.validate(value), e);
  }

  render() {
    const {
      className,
      label,
      icon,
      required,
      value,
      children,
      onChange,
      ...otherProps,
    } = this.props;

    return (
      <div className={style.wrap}>
        <div className={style.label}>
          {icon && cloneElement(icon, {className: style.icon})}
          <span>{label}</span>
          {!icon && required && <span className={style.required}>*</span>}
        </div>
        <div className={style.area}>
          <select
            {...otherProps}
            className={c(style.select, className)}
            value={(_.isUndefined(value) || _.isNull(value)) ? '' : value}
            onChange={(e) => onChange(e.target.value, e)}>
            {!value && <InputSelectOption key="-1" value="" disabled>請選擇</InputSelectOption>}
            {children}
          </select>
        </div>
      </div>
    );
  }
}