import React, {PropTypes, cloneElement} from 'react';
import c from 'classnames';

import style from './input-text.css';

export default class extends React.Component {
  displayName: 'InputText'
  
  static propTypes = {
    label: PropTypes.string.isRequired,
    className: PropTypes.string,
    icon: PropTypes.element,
    placeholder: PropTypes.string,
    error: PropTypes.string,
    required: PropTypes.bool,
    value: PropTypes.string,
    onChange: PropTypes.func,
  }

  static defaultProps = {
    className: null,
    icon: null,
    placeholder: '',
    error: '',
    value: '',
    required: false,
    onChange: () => {},
  }

  componentDidMount() {
    const { value, onChange } = this.props;

    onChange(value, this.validate(value));
  }

  componentDidUpdate(prevProps) {
    const { required, value, onChange } = this.props;

    if (prevProps.required !== required || prevProps.value !== value) {
      onChange(value, this.validate(value));
    }
  }

  validate(value) {
    const { required, onChange } = this.props;

    return required && !value ? '是必要欄位' : null;
  }
  
  onChange = (e) => {
    const value = e.target.value;

    this.props.onChange(value, this.validate(value), e);
  }

  render () {
    const {
      icon,
      label,
      className,
      placeholder,
      required,
      onChange,
    } = this.props;

    return (
      <div className={style.wrap}>
        <div className={style.label}>
          <span>{label}</span>
          {icon && cloneElement(icon, {className: style.icon})}
          {!icon && required && <span className={style.required}>*</span>}
        </div>
        <div className={style.area}>
          <input
            {...this.props}
            onChange={this.onChange}
            placeholder={placeholder}
            className={c(style.input, className)} />
        </div>
      </div>
    );
  }
}
