import React, {PropTypes, cloneElement} from 'react';
import moment from 'moment';
import c from 'classnames';
import { mapPropsOnChange } from 'recompose';

import InputText from '../input-text/input-text'

@mapPropsOnChange(
  ['value'],
  ({value, ...props}) => ({
    value,
    time: value ? moment(value).format('HH:mm') : null,
    ...props,
  })
)
export default class extends React.Component {
  displayName: 'InputTime'
  
  static propTypes = {
    value: PropTypes.instanceOf(Date),
    time: PropTypes.string,
    onChange: PropTypes.func,
  }

  static defaultProps = {
    onChange: () => {},
  }

  onChange = (current, valid) => {
    const { onChange, value } = this.props;

    if (current) {
      current = moment(current, "HH:mm");

      if (value) current = moment(value).set({
        hour: current.get('hour'),
        minute: current.get('minute'),
      });

      current = current.toDate();
    }

    onChange(current, valid);
  }

  render () {
    const {
      onChange,
      value,
      time,
      ...otherProps,
    } = this.props;

    return (
      <InputText {...otherProps} onChange={this.onChange} value={time} type="time" />
    );
  }
}
