import React, {PropTypes} from 'react'
import c from 'classnames'
import { mapPropsOnChange } from 'recompose';

import style from './input-toggle.css'

class On extends React.Component {
  render() {
    return (
      <svg width="14" height="11" viewBox="0 0 14 11" xmlns="http://www.w3.org/2000/svg">
        <title>
          switch-check
        </title>
        <path d="M11.264 0L5.26 6.004 2.103 2.847 0 4.95l5.26 5.26 8.108-8.107L11.264 0" fill="#fff" fill-rule="evenodd"/>
      </svg>
    )
  }
}

class Off extends React.Component {
  render() {
    return (
      <svg width="10" height="10" viewBox="0 0 10 10" xmlns="http://www.w3.org/2000/svg">
        <title>
          switch-x
        </title>
        <path d="M9.9 2.12L7.78 0 4.95 2.828 2.12 0 0 2.12l2.83 2.83L0 7.776 2.123 9.9 4.95 7.07 7.78 9.9 9.9 7.776 7.072 4.95 9.9 2.12" fill="#fff" fill-rule="evenodd"/>
      </svg>
    )
  }
}

@mapPropsOnChange(
  ['value'],
  ({value, ...props}) => ({
    value: !!value,
    ...props,
  })
)
export default class extends React.Component {
  displayName: 'InputToggle'

  static propTypes = {
    value: PropTypes.bool,
    disabled: PropTypes.bool,
    onChange: PropTypes.func,
    label: PropTypes.string,
  }

  static defaultProps = {
    value: false,
    disabled: false,
  }

  componentDidMount() {
    const { value, onChange } = this.props;

    onChange(value);
  }

  onClick = (e) => {
    e.preventDefault();

    const { value, onChange } = this.props;

    onChange(!value);
  }

  render() {
    const {
      value,
      disabled,
      className,
      label,
    } = this.props;

    return (
      <label className={c(style.wrapper, className)} onClick={this.onClick}>
        <div className={c(style.toggle, value && style.checked, disabled && style.disabled)}>
          <div className={style.track}>
            <div className={style.on}><On /></div>
            <div className={style.off}><Off /></div>
          </div>
          <div className={style.thumb}></div>
          <input className={style.input} type="checkbox" onChange={() => {}} checked={value} />
        </div>
        <span className={style.label}>{label}</span>
      </label>
    )
  }
}