const webpack = require('webpack');
const path = require('path');
const buildPath = path.resolve(__dirname, 'build');
const nodeModulesPath = path.resolve(__dirname, 'node_modules');
const TransferWebpackPlugin = require('transfer-webpack-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

const config = {
  entry: [
    'webpack/hot/dev-server',
    'webpack/hot/only-dev-server',
    path.join(__dirname, '/src/dev.jsx'),
  ],
  resolve: {
    extensions: ["", ".js", ".jsx", ".css"],
  },
  devServer:{
    contentBase: 'src',
    devtool: 'eval',
    hot: true,
    inline: true,
    port: 3000,
  },
  devtool: 'eval',
  output: {
    path: buildPath,
    filename: '[name].js',
  },
  plugins: [
    new webpack.HotModuleReplacementPlugin(),
    new webpack.NoErrorsPlugin(),
    new ExtractTextPlugin('style.css', { allChunks: true }),
  ],
  module: {
    preLoaders: [
      {
        test: /\.(js|jsx)$/,
        loader: 'eslint-loader',
        include: [path.resolve(__dirname, "src/dev")],
        exclude: [nodeModulesPath],
      },
    ],
    loaders: [
      {
        test: /\.(js|jsx)$/,
        loaders: ['react-hot','babel-loader?optional=runtime'],
        exclude: [nodeModulesPath],
      },
      {
        test: /\.css$/,
        loader: ExtractTextPlugin.extract('style-loader',
        'css-loader?modules&importLoaders=1&localIdentName=[name]__[local]!postcss-loader'),
      },
      {
        test: /\.woff$/,
        loader: 'file-loader?name=fonts/[name].[ext]',
      },
      { 
        test: /\.svg$/,
        loader: "url-loader?limit=10000&mimetype=image/svg+xml",
      },
      {
        test: /\.png$/,
        loader: "url-loader?mimetype=image/png",
      },
    ],
  },
  postcss: [
    require('autoprefixer'),
    require('postcss-color-rebeccapurple'),
  ],
  eslint: {
    configFile: '.eslintrc',
  },
};

module.exports = config;
